/*
 *  (C) Copyright IX 2004 Michal 'GiM' Spadlinski <gim at skrzynka dot pl>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include "coolstorage.h"

int strs_init (struct strs_t *m)
{
	m->strs = NULL;
	m->num = m->act = 0;
	return 0;
}

int strs_add(struct strs_t *m, char *str, int alloc)
{
	if (m->act == m->num)
	{
		m->num+=STRS_M;
		m->strs = (char **)
			realloc(m->strs, (m->num)*sizeof(char *));
		if (!m->strs)
			return -1;
	}
	m->strs[m->act] = alloc?strdup(str):str;
	if (!m->strs[m->act])
		return -1;
	m->act++;
	return 0;
}

int strs_free(struct strs_t *p, int release)
{
	int i;
	char *x;
	if (release)
		for (i=0; i<p->act; i++)
			free(p->strs[i]);
	free(p->strs);
	p->strs = NULL;
}

/*
 *  example how to use: 
int main(int argc, char **argv)
{
	struct strs_t ding;
	int i;

	strs_init(&ding);

	for (i=0; i<argc; i++)
		strs_add(&ding, argv[i], 1);

	for (i=0; i<ding.act; i++)
		printf("%d %08X - %s\n", i, ding.strs[i], ding.strs[i]);

	qsort(ding.strs, ding.act, sizeof(char *), gstrcmp);
	puts("");

	for (i=0; i<ding.act; i++)
		printf("%d %08X - %s\n", i, ding.strs[i], ding.strs[i]);

	strs_free(&ding, 1);
	return 0;
}
 *
 */
